@@ -1,5 +1,17 @@
 svc <- paws::cloudwatchlogs()
 
+test_that("describe_deliveries", {
+  expect_error(svc$describe_deliveries(), NA)
+})
+
+test_that("describe_delivery_destinations", {
+  expect_error(svc$describe_delivery_destinations(), NA)
+})
+
+test_that("describe_delivery_sources", {
+  expect_error(svc$describe_delivery_sources(), NA)
+})
+
 test_that("describe_destinations", {
   expect_error(svc$describe_destinations(), NA)
 })
@@ -31,3 +43,11 @@ test_that("describe_query_definitions", {
 test_that("describe_resource_policies", {
   expect_error(svc$describe_resource_policies(), NA)
 })
+
+test_that("list_anomalies", {
+  expect_error(svc$list_anomalies(), NA)
+})
+
+test_that("list_log_anomaly_detectors", {
+  expect_error(svc$list_log_anomaly_detectors(), NA)
+})
